function RBDual = trainDualRB_Greedy(prob,Xi_train,Norm,Nmax,tol)

%% Initialize parameters and storage

  Nmax = eval('Nmax','100');
  tol = eval('tol','5e-6');

% store Xi_train  
  RBDual.Xi_train = Xi_train;
% store norm to be used  
  RBDual.Norm = Norm;
  if isfield(prob.fem.innProd, 'refparam')
      RBDual.innProd.refparam = prob.fem.innProd.refparam;
  end
  if isfield(prob.fem.innProd, 'refalpha')
      RBDual.innProd.refalpha = prob.fem.innProd.refalpha;
  end
  if isfield(prob.fem.innProd, 'refthetas')
      RBDual.innProd.refthetas = prob.fem.innProd.refthetas;
end
  
% store theta function for both sides and initialize RB matrices
  RBDual.pre.rhs.theta = prob.fem.pre.out.theta;
  RBDual.pre.lhs = struct('theta',{}, 'K',{});
  RBDual.pre.rhs.L = [];
  for q=1:length(prob.fem.pre.lhs)
    RBDual.pre.lhs(q).theta = prob.fem.pre.lhs(q).theta;
  end
  
  
% initialize S, Basis and Riesz Representors
  RBDual.S = zeros(size(Xi_train,1),0);
  RBDual.Basis = zeros(prob.fem.dof.num,0);
  RBDual.RieszReprs = zeros(length(prob.fem.dof.ind),0);
  RBDual.innProdRieszReprs = [];
  RBDual.Greedy_errors = [];
  RBDual.Nmax = 0;
  
  % compute Riesz representors 
  innProd = prob.fem.innProd.(RBDual.Norm);
  innProd = innProd(prob.fem.dof.ind,prob.fem.dof.ind);
% ... for rhs 
  for q=1:size(prob.fem.pre.out.theta,2)
    RBDual.RieszReprs(:,end+1) = ...
            innProd\(-prob.fem.pre.out.L(prob.fem.dof.ind,q));
  end  
  RBDual.innProdRieszReprs = RBDual.RieszReprs'*innProd*RBDual.RieszReprs;
  
%% Training Dual
  
% start greedy
  while (size(RBDual.Basis,2)<Nmax)

  % compute error estimator for all remaining values in Xi_train
    errEst = ones(size(Xi_train,2),1);

    for i=1:length(errEst)
      mu = Xi_train(:,i);
    % compute RB approximation
      z_apprCoeffs = getRBAppr(RBDual, mu);
    % compute error estimator  
      errEst(i) = getErrEst(RBDual,mu,z_apprCoeffs);
    end

  % determine index of argmax in Xi_train
    [errEst_max,errEst_max_ind] = max(errEst);
    
  % store Greedy errors
    RBDual.Greedy_errors(end+1) = errEst_max;

  % break, if maximum error estimator is less than tol
    if (errEst_max<tol)
      break;
    end
    
  % add solution for identified parameter to basis
    RBDual = addDualBasisFun(prob,RBDual,Xi_train(:,errEst_max_ind));

  % remove identified parameter from Xi_train  
    Xi_train(:,errEst_max_ind) = [];
    
  end
  
% store Nmax
  RBDual.Nmax = size(RBDual.Basis,2);

end  
  
%% add orthonormalized u(mu) to RB basis
function RBDual = addDualBasisFun(prob,RBDual,mu)

% compute solution
  u = getDualSol(prob,mu);

% orthonormalize 
  if (size(RBDual.S,2)==0)
    r = u;
  else
    r = u - RBDual.Basis*(RBDual.Basis'*prob.fem.innProd.(RBDual.Norm)*u);
  end
  RBDual.Basis(:,end+1) = r/sqrt(r'*prob.fem.innProd.(RBDual.Norm)*r);

% compute new pre-assembled RB quantities
  % lhs
  for q=1:size(prob.fem.pre.lhs,2)
    RBDual.pre.lhs(q).K = zeros(size(RBDual.Basis,2));
    K = RBDual.Basis'*prob.fem.pre.lhs(q).K*RBDual.Basis;
    % transpose lhs! 
    RBDual.pre.lhs(q).K = K';
  end
  % rhs
  RBDual.pre.rhs.L = -RBDual.Basis'*prob.fem.pre.out.L;

% compute Riesz representors
  innProd = prob.fem.innProd.(RBDual.Norm);
  innProd = innProd(prob.fem.dof.ind,prob.fem.dof.ind);
% ... for lhs
  for q=1:size(RBDual.pre.lhs,2)
    Kn = (-RBDual.Basis(:,end)' * prob.fem.pre.lhs(q).K)';
    RBDual.RieszReprs(:,end+1) = innProd\Kn(prob.fem.dof.ind);
  end
% compute inner product of duals
  RBDual.innProdRieszReprs = RBDual.RieszReprs'*innProd*RBDual.RieszReprs;
  
  % additionally compute components of primal residual for dual basis
  % functions
  for q=1:size(prob.fem.pre.lhs,2)
    RBDual.pre.res.lhs(q).K = zeros(size(RBDual.Basis,2));
    K = RBDual.Basis'*prob.fem.pre.lhs(q).K*prob.RB.Basis;
    RBDual.pre.res.lhs(q).K = K;
  end
  RBDual.pre.res.L = RBDual.Basis' * prob.fem.pre.rhs.L;
  
% add mu to S
  RBDual.S = [RBDual.S mu];  
end  